@@ -36,10 +36,13 @@ class ImageStream(NamespacedResource):
         self.lookup_policy = lookup_policy
 
     def to_dict(self):
-        res = super().to_dict()
-        if self.yaml_file:
-            return res
-        res.update(
-            {"spec": {"lookupPolicy": {"local": self.lookup_policy}, "tags": self.tags}}
-        )
-        return res
+        super().to_dict()
+        if not self.yaml_file:
+            self.res.update(
+                {
+                    "spec": {
+                        "lookupPolicy": {"local": self.lookup_policy},
+                        "tags": self.tags,
+                    }
+                }
+            )
