@@ -3,15 +3,11 @@ import json
 import kubernetes
 
 from ocp_resources.constants import TIMEOUT_4MINUTES
-from ocp_resources.logger import get_logger
 from ocp_resources.node import Node
 from ocp_resources.resource import NamespacedResource, kube_v1_api
 from ocp_resources.utils import TimeoutWatch
 
 
-LOGGER = get_logger(name=__name__)
-
-
 class ExecOnPodError(Exception):
     def __init__(self, command, rc, out, err):
         self.cmd = command
@@ -91,7 +87,7 @@ class Pod(NamespacedResource):
         """
         error_channel = {}
         stream_closed_error = "stream resp is closed"
-        LOGGER.info(f"Execute {command} on {self.name} ({self.node.name})")
+        self.logger.info(f"Execute {command} on {self.name} ({self.node.name})")
         resp = kubernetes.stream.stream(
             api_method=self._kube_v1_api.connect_get_namespaced_pod_exec,
             name=self.name,
